==> moniwiki-1.0.tgz: moniwiki/plugin/WordIndex.php <==
<?php
// Copyright 2003 by Won-Kyu Park <wkpark at kldp.org>
// All rights reserved. Distributable under GPL see COPYING
// a WordIndex plugin for the MoniWiki
//
// Usage: [[WordIndex]]
//
// $Id: WordIndex.php,v 1.1 2003/08/06 19:00:17 wkpark Exp wkpark $
// vim:et:ts=2:

function macro_WordIndex($formatter,$value) {
  global $DBInfo;

  $all_pages= $DBInfo->getPageLists();

  if ($DBInfo->use_titlecache) {
    $cache=new Cache_text('title');
  }

  foreach ($all_pages as $page) {
    if ($DBInfo->use_titlecache and $cache->exists($page))
      $title=$cache->fetch($page);
    else
      $title=$page;
    $tmp=preg_replace("/[\?!$%\.\^;&\*()_\+\|\[\] \-~\/]/"," ",$title);
    $tmp=preg_replace("/((?<=[A-Za-z0-9])[A-Z][a-z0-9])/"," \\1",ucwords($tmp));
    $words=preg_split("/\s+/",$tmp);
    foreach ($words as $word) {
      if ($dict[$word])
        $dict[$word][]=$page;
      else
        $dict[$word]=array($page);
    }
  }
  #ksort($dict);
  uksort($dict, "strnatcasecmp");

  $key=-1;
  $out="";
  $keys=array();
  foreach ($dict as $word=>$pages) {
    $pkey=get_key($word);
#   $key=strtoupper($page[0]);
    if ($key != $pkey) {
      if ($key !=-1)
        $out.="</ul>";
      $key=$pkey;
      $keys[]=$key;
      $out.= "<a name='$key' /><h3><a href='#top'>$key</a></h3>\n";
    }

    $out.= "<h4>$word</h4>\n";
    $out.= "<ul>\n";
    foreach ($pages as $page)
      $out.= '<li>' . $formatter->word_repl($page)."</li>\n";
    $out.= "</ul>\n";
  }

  $index="";
  foreach ($keys as $key)
    $index.= "| <a href='#$key'>$key</a> ";
  $index[0]=" ";

  return "<center><a name='top' />$index</center>\n$out";
}

?>

==> moniwiki-1.0.2.tgz: moniwiki/plugin/WordIndex.php <==
<?php
// Copyright 2003 by Won-Kyu Park <wkpark at kldp.org>
// All rights reserved. Distributable under GPL see COPYING
// a WordIndex plugin for the MoniWiki
//
// Usage: [[WordIndex]]
//
// $Id: WordIndex.php,v 1.3 2003/08/13 21:34:05 wkpark Exp $
// vim:et:ts=2:

function macro_WordIndex($formatter,$value) {
  global $DBInfo;

  $all_pages= $DBInfo->getPageLists();

  if ($DBInfo->use_titlecache) {
    $cache=new Cache_text('title');
  }

  foreach ($all_pages as $page) {
    if ($DBInfo->use_titlecache and $cache->exists($page))
      $title=$cache->fetch($page);
    else
      $title=$page;
    $tmp=preg_replace("/[\?!$%\.\^;&\*()_\+\|\[\] \-~\/]/"," ",$title);
    $tmp=preg_replace("/((?<=[A-Za-z0-9])[A-Z][a-z0-9])/"," \\1",ucwords($tmp));
    $words=preg_split("/\s+/",$tmp);
    foreach ($words as $word) {
      if ($dict[$word])
        $dict[$word][]=$page;
      else
        $dict[$word]=array($page);
    }
  }
  #ksort($dict);
  uksort($dict, "strnatcasecmp");

  $key=-1;
  $out="";
  $keys=array();
  foreach ($dict as $word=>$pages) {
    $pkey=get_key($word);
#   $key=strtoupper($page[0]);
    if ($key != $pkey) {
      if ($key !=-1)
        $out.="</ul>";
      $key=$pkey;
      $keys[]=$key;
      $out.= "<a name='$key' /><h3><a href='#top'>$key</a></h3>\n";
    }

    $out.= "<h4>$word</h4>\n";
    $out.= "<ul>\n";
    foreach ($pages as $page)
      $out.= '<li>' . $formatter->word_repl('"'.$page.'"')."</li>\n";
    $out.= "</ul>\n";
  }

  $index="";
  foreach ($keys as $key)
    $index.= "| <a href='#$key'>$key</a> ";
  $index[0]=" ";

  return "<center><a name='top' />$index</center>\n$out";
}

?>
